@@ -7,6 +7,11 @@ use warnings;
 
 
 system "echo .dump | sqlite-2.8.14.bin cpants.db_original > dump.data";
+print "In this version I did some manual cleaning\n";
+print "If you'd like to setup your own version you'll have to do it yourself too :-)\n";
+exit;
+
+
 open IN, "dump.data";
 open OUT, ">changed.data";
 my $create;
@@ -15,23 +20,24 @@ my $modules = 1;
 while (<IN>) {
 
 	# removing some fancy database stuff that SQL::Parser cannot handle
-	s/default 0//;
-	s/unsigned//;
-	s/ float/ varchar(20)/;
-	s/ int\s/ integer/;
-	s/bigint/integer/;
-	s/tinyint/integer/;
-	s/date date/date varchar(30)/;
-	s/not null//;
+	# a missing primary key   entry
+	s/default 0//;           # still here
+	s/ unsigned//;           # still here
+	s/ float/ varchar(20)/;  # still here
+	s/ int\s/ integer/;      # still here
+#	s/ bigint/ integer/;       
+#	s/ tinyint/ integer/;
+#	s/date date/date varchar(30)/;
+#	s/not null//;
 	next if /^INSERT INTO authors VALUES\(NULL,NULL,NULL,0,0\);/;
 
 
 	if ($create) {
-		if ($create eq "prereq") {
-			print OUT "  id integer primary key,\n",
-		} elsif ($create eq "modules") {
-			print OUT "  id integer primary key,\n",
-		} else {
+		#if ($create eq "prereq") {
+		#	print OUT "  id integer primary key,\n",
+		#} elsif ($create eq "modules") {
+		#	print OUT "  id integer primary key,\n",
+		#} else {
 			s/,/ primary key,/; # set the first column of every table except the above 2 
 		}
 	}
@@ -57,4 +63,4 @@ close IN;
 close OUT;
 
 unlink "cpants.db";
-system "sqlite-2.8.14.bin cpants.db < changed.data";
+#system "sqlite-2.8.14.bin cpants.db < changed.data";
